Changelog
=========

0.3 (2019-09-07)
----------------

- Fix "ModuleNotFoundError: No module named 'src'" error for pip install.


0.2 (2019-09-07)
----------------

- Fix setup classifier for a clean release


0.1 (2019-09-07)
----------------

- KRCG tool, initial version.
